smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer

# ``smartcard`.`pyro`.`server`.`RemoteReaderServer`.`RemoteReaderServer``

class documentation

`class RemoteReaderServer(ReaderObserver):`

View In Hierarchy

Monitor local readers, and publish them as remote pyro readers.

Method | `__init__` | Starts pyro name server and constructs reader name space.
Method | `start` | Start pyro daemon and accept incoming requests.
Method | `update` | Called when a local reader is added or removed. Create remote pyro reader objects for added readers. Delete remote pyro reader objects for removed readers.
Instance Variable | `daemon` | Undocumented
Instance Variable | `ns` | Undocumented
Instance Variable | `pn` | Undocumented
Instance Variable | `remotereaders` | Undocumented

def __init__(self):
overrides `smartcard.ReaderMonitoring.ReaderObserver.__init__`

Starts pyro name server and constructs reader name space.

def start(self):

Start pyro daemon and accept incoming requests.

def update(self, observable, actions):
overrides `smartcard.ReaderMonitoring.ReaderObserver.update`

Called when a local reader is added or removed. Create remote pyro reader objects for added readers. Delete remote pyro reader objects for removed readers.

daemon =

Undocumented

ns =

Undocumented

pn =

Undocumented

remotereaders: `dict` =

Undocumented